@@ -50,9 +50,7 @@ class CfnDataCatalog(
         name: str,
         type: str,
         description: typing.Optional[str] = None,
-        parameters: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
-        ] = None,
+        parameters: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]] = None,
         tags: typing.Optional["TagsProperty"] = None,
     ) -> None:
         """Create a new ``AWS::Athena::DataCatalog``.
@@ -162,9 +160,7 @@ class CfnDataCatalog(
     @jsii.member(jsii_name="parameters")
     def parameters(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]]:
         """``AWS::Athena::DataCatalog.Parameters``.
 
         see
@@ -175,9 +171,7 @@ class CfnDataCatalog(
     @parameters.setter
     def parameters(
         self,
-        value: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]],
     ) -> None:
         jsii.set(self, "parameters", value)
 
@@ -239,9 +233,7 @@ class CfnDataCatalogProps:
         name: str,
         type: str,
         description: typing.Optional[str] = None,
-        parameters: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
-        ] = None,
+        parameters: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]] = None,
         tags: typing.Optional["CfnDataCatalog.TagsProperty"] = None,
     ) -> None:
         """Properties for defining a ``AWS::Athena::DataCatalog``.
@@ -298,9 +290,7 @@ class CfnDataCatalogProps:
     @builtins.property
     def parameters(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Mapping[str, str]]]:
         """``AWS::Athena::DataCatalog.Parameters``.
 
         see
@@ -575,26 +565,11 @@ class CfnWorkGroup(
         *,
         name: str,
         description: typing.Optional[str] = None,
-        recursive_delete_option: typing.Optional[
-            typing.Union[bool, aws_cdk.core.IResolvable]
-        ] = None,
+        recursive_delete_option: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         state: typing.Optional[str] = None,
-        tags: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]
-                ],
-            ]
-        ] = None,
-        work_group_configuration: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationProperty"]
-        ] = None,
-        work_group_configuration_updates: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "WorkGroupConfigurationUpdatesProperty"
-            ]
-        ] = None,
+        tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]]]] = None,
+        work_group_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationProperty"]] = None,
+        work_group_configuration_updates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationUpdatesProperty"]] = None,
     ) -> None:
         """Create a new ``AWS::Athena::WorkGroup``.
 
@@ -734,9 +709,7 @@ class CfnWorkGroup(
     @jsii.member(jsii_name="workGroupConfiguration")
     def work_group_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationProperty"]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfiguration``.
 
         see
@@ -747,9 +720,7 @@ class CfnWorkGroup(
     @work_group_configuration.setter
     def work_group_configuration(
         self,
-        value: typing.Optional[
-            typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationProperty"]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationProperty"]],
     ) -> None:
         jsii.set(self, "workGroupConfiguration", value)
 
@@ -757,9 +728,7 @@ class CfnWorkGroup(
     @jsii.member(jsii_name="workGroupConfigurationUpdates")
     def work_group_configuration_updates(
         self,
-    ) -> typing.Optional[
-        typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationUpdatesProperty"]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationUpdatesProperty"]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfigurationUpdates``.
 
         see
@@ -770,11 +739,7 @@ class CfnWorkGroup(
     @work_group_configuration_updates.setter
     def work_group_configuration_updates(
         self,
-        value: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "WorkGroupConfigurationUpdatesProperty"
-            ]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkGroupConfigurationUpdatesProperty"]],
     ) -> None:
         jsii.set(self, "workGroupConfigurationUpdates", value)
 
@@ -841,12 +806,7 @@ class CfnWorkGroup(
         def __init__(
             self,
             *,
-            encryption_configuration: typing.Optional[
-                typing.Union[
-                    aws_cdk.core.IResolvable,
-                    "CfnWorkGroup.EncryptionConfigurationProperty",
-                ]
-            ] = None,
+            encryption_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EncryptionConfigurationProperty"]] = None,
             output_location: typing.Optional[str] = None,
         ) -> None:
             """
@@ -865,11 +825,7 @@ class CfnWorkGroup(
         @builtins.property
         def encryption_configuration(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "CfnWorkGroup.EncryptionConfigurationProperty"
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EncryptionConfigurationProperty"]]:
             """``CfnWorkGroup.ResultConfigurationProperty.EncryptionConfiguration``.
 
             see
@@ -911,19 +867,10 @@ class CfnWorkGroup(
         def __init__(
             self,
             *,
-            encryption_configuration: typing.Optional[
-                typing.Union[
-                    aws_cdk.core.IResolvable,
-                    "CfnWorkGroup.EncryptionConfigurationProperty",
-                ]
-            ] = None,
+            encryption_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EncryptionConfigurationProperty"]] = None,
             output_location: typing.Optional[str] = None,
-            remove_encryption_configuration: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
-            remove_output_location: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
+            remove_encryption_configuration: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
+            remove_output_location: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         ) -> None:
             """
             :param encryption_configuration: ``CfnWorkGroup.ResultConfigurationUpdatesProperty.EncryptionConfiguration``.
@@ -940,20 +887,14 @@ class CfnWorkGroup(
             if output_location is not None:
                 self._values["output_location"] = output_location
             if remove_encryption_configuration is not None:
-                self._values[
-                    "remove_encryption_configuration"
-                ] = remove_encryption_configuration
+                self._values["remove_encryption_configuration"] = remove_encryption_configuration
             if remove_output_location is not None:
                 self._values["remove_output_location"] = remove_output_location
 
         @builtins.property
         def encryption_configuration(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "CfnWorkGroup.EncryptionConfigurationProperty"
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EncryptionConfigurationProperty"]]:
             """``CfnWorkGroup.ResultConfigurationUpdatesProperty.EncryptionConfiguration``.
 
             see
@@ -1019,20 +960,10 @@ class CfnWorkGroup(
             self,
             *,
             bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number] = None,
-            enforce_work_group_configuration: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
-            publish_cloud_watch_metrics_enabled: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
-            requester_pays_enabled: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
-            result_configuration: typing.Optional[
-                typing.Union[
-                    aws_cdk.core.IResolvable, "CfnWorkGroup.ResultConfigurationProperty"
-                ]
-            ] = None,
+            enforce_work_group_configuration: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
+            publish_cloud_watch_metrics_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
+            requester_pays_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
+            result_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.ResultConfigurationProperty"]] = None,
         ) -> None:
             """
             :param bytes_scanned_cutoff_per_query: ``CfnWorkGroup.WorkGroupConfigurationProperty.BytesScannedCutoffPerQuery``.
@@ -1046,17 +977,11 @@ class CfnWorkGroup(
             """
             self._values = {}
             if bytes_scanned_cutoff_per_query is not None:
-                self._values[
-                    "bytes_scanned_cutoff_per_query"
-                ] = bytes_scanned_cutoff_per_query
+                self._values["bytes_scanned_cutoff_per_query"] = bytes_scanned_cutoff_per_query
             if enforce_work_group_configuration is not None:
-                self._values[
-                    "enforce_work_group_configuration"
-                ] = enforce_work_group_configuration
+                self._values["enforce_work_group_configuration"] = enforce_work_group_configuration
             if publish_cloud_watch_metrics_enabled is not None:
-                self._values[
-                    "publish_cloud_watch_metrics_enabled"
-                ] = publish_cloud_watch_metrics_enabled
+                self._values["publish_cloud_watch_metrics_enabled"] = publish_cloud_watch_metrics_enabled
             if requester_pays_enabled is not None:
                 self._values["requester_pays_enabled"] = requester_pays_enabled
             if result_configuration is not None:
@@ -1107,11 +1032,7 @@ class CfnWorkGroup(
         @builtins.property
         def result_configuration(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "CfnWorkGroup.ResultConfigurationProperty"
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.ResultConfigurationProperty"]]:
             """``CfnWorkGroup.WorkGroupConfigurationProperty.ResultConfiguration``.
 
             see
@@ -1147,24 +1068,11 @@ class CfnWorkGroup(
             self,
             *,
             bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number] = None,
-            enforce_work_group_configuration: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
-            publish_cloud_watch_metrics_enabled: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
-            remove_bytes_scanned_cutoff_per_query: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
-            requester_pays_enabled: typing.Optional[
-                typing.Union[bool, aws_cdk.core.IResolvable]
-            ] = None,
-            result_configuration_updates: typing.Optional[
-                typing.Union[
-                    aws_cdk.core.IResolvable,
-                    "CfnWorkGroup.ResultConfigurationUpdatesProperty",
-                ]
-            ] = None,
+            enforce_work_group_configuration: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
+            publish_cloud_watch_metrics_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
+            remove_bytes_scanned_cutoff_per_query: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
+            requester_pays_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
+            result_configuration_updates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.ResultConfigurationUpdatesProperty"]] = None,
         ) -> None:
             """
             :param bytes_scanned_cutoff_per_query: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.BytesScannedCutoffPerQuery``.
@@ -1179,27 +1087,17 @@ class CfnWorkGroup(
             """
             self._values = {}
             if bytes_scanned_cutoff_per_query is not None:
-                self._values[
-                    "bytes_scanned_cutoff_per_query"
-                ] = bytes_scanned_cutoff_per_query
+                self._values["bytes_scanned_cutoff_per_query"] = bytes_scanned_cutoff_per_query
             if enforce_work_group_configuration is not None:
-                self._values[
-                    "enforce_work_group_configuration"
-                ] = enforce_work_group_configuration
+                self._values["enforce_work_group_configuration"] = enforce_work_group_configuration
             if publish_cloud_watch_metrics_enabled is not None:
-                self._values[
-                    "publish_cloud_watch_metrics_enabled"
-                ] = publish_cloud_watch_metrics_enabled
+                self._values["publish_cloud_watch_metrics_enabled"] = publish_cloud_watch_metrics_enabled
             if remove_bytes_scanned_cutoff_per_query is not None:
-                self._values[
-                    "remove_bytes_scanned_cutoff_per_query"
-                ] = remove_bytes_scanned_cutoff_per_query
+                self._values["remove_bytes_scanned_cutoff_per_query"] = remove_bytes_scanned_cutoff_per_query
             if requester_pays_enabled is not None:
                 self._values["requester_pays_enabled"] = requester_pays_enabled
             if result_configuration_updates is not None:
-                self._values[
-                    "result_configuration_updates"
-                ] = result_configuration_updates
+                self._values["result_configuration_updates"] = result_configuration_updates
 
         @builtins.property
         def bytes_scanned_cutoff_per_query(self) -> typing.Optional[jsii.Number]:
@@ -1257,12 +1155,7 @@ class CfnWorkGroup(
         @builtins.property
         def result_configuration_updates(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                "CfnWorkGroup.ResultConfigurationUpdatesProperty",
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.ResultConfigurationUpdatesProperty"]]:
             """``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.ResultConfigurationUpdates``.
 
             see
@@ -1301,29 +1194,11 @@ class CfnWorkGroupProps:
         *,
         name: str,
         description: typing.Optional[str] = None,
-        recursive_delete_option: typing.Optional[
-            typing.Union[bool, aws_cdk.core.IResolvable]
-        ] = None,
+        recursive_delete_option: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         state: typing.Optional[str] = None,
-        tags: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]
-                ],
-            ]
-        ] = None,
-        work_group_configuration: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationProperty"
-            ]
-        ] = None,
-        work_group_configuration_updates: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty",
-            ]
-        ] = None,
+        tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]]]] = None,
+        work_group_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationProperty"]] = None,
+        work_group_configuration_updates: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Athena::WorkGroup``.
 
@@ -1352,9 +1227,7 @@ class CfnWorkGroupProps:
         if work_group_configuration is not None:
             self._values["work_group_configuration"] = work_group_configuration
         if work_group_configuration_updates is not None:
-            self._values[
-                "work_group_configuration_updates"
-            ] = work_group_configuration_updates
+            self._values["work_group_configuration_updates"] = work_group_configuration_updates
 
     @builtins.property
     def name(self) -> str:
@@ -1397,12 +1270,7 @@ class CfnWorkGroupProps:
     @builtins.property
     def tags(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, aws_cdk.core.CfnTag]]]]:
         """``AWS::Athena::WorkGroup.Tags``.
 
         see
@@ -1413,11 +1281,7 @@ class CfnWorkGroupProps:
     @builtins.property
     def work_group_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationProperty"
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationProperty"]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfiguration``.
 
         see
@@ -1428,12 +1292,7 @@ class CfnWorkGroupProps:
     @builtins.property
     def work_group_configuration_updates(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty",
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.WorkGroupConfigurationUpdatesProperty"]]:
         """``AWS::Athena::WorkGroup.WorkGroupConfigurationUpdates``.
 
         see
